#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}

status=0

command="../sbin/mkgeo_grid_3d 5 > box-5.geo"
echo "      $command"
eval        $command
command="./find_close_vertex_tst box-5.geo 1.2 0.6 0.7 -noplot"
echo "      $command"
eval        $command >/dev/null 2>/dev/null
if test $? -ne 0; then status=1; echo "        => *NO*"; fi
command="rm -f box-5.geo"
echo "      $command"
eval        $command

exit $status
